import inspect
from typing import Any

from nbdev.showdoc import show_doc


def show_doc_enhanced(element, show_methods=False, **kwargs):
    """Utility for nbdev to generate docs of all public methods of a class"""
    if not show_methods:
        return show_doc(element, **kwargs)

    for name, func in inspect.getmembers(element, predicate=inspect.isroutine):
        if name == name.lstrip("_"):
            try:
                show_doc(func, **kwargs)
            except NameError:
                print(f"Doc will be shown for: {func.__qualname__}.{name}")



"""
Clean Documentation generated by nbdev
"""
import re
from pathlib import Path

DOC_ROOT = Path(__file__).parent.parent / "docs"

def fix_sidebar():
    """Fix links in sidebar (module.html instead of /module)"""
    for file in ("sidebar.json", "_data/sidebars/home_sidebar.yml"):
        path = DOC_ROOT / file
        if not path.is_file():
            continue

        content = path.read_text(encoding="utf-8", errors="surrogateescape")
        new_content = re.sub(r"(\w+)\.html", r"/\1", content)
        path.write_text(new_content, encoding="utf-8")
        if new_content != content:
            print(f"Cleaned: documentation links in {path}")

if __name__ == "__main__":
    fix_sidebar()
